Documentation
¶
Index ¶
Constants ¶
const ( NotFound = "not-found" BadID = "bad-id" )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AlertCache ¶
type AlertCache interface {
GetIssue(string) (structs.RoomIssue, *nerr.E)
GetAllIssues() ([]structs.RoomIssue, *nerr.E)
PutIssue(structs.RoomIssue) *nerr.E
DeleteIssue(string) *nerr.E
}
NOTE: the assumption is that the alert caches are NOT safe for concurrent access, concurrency saftey is handled at a higher level.
func GetAlertCache ¶
func GetAlertCache(name string) AlertCache
type RedisAlertCache ¶
type RedisAlertCache struct {
// contains filtered or unexported fields
}
func (*RedisAlertCache) DeleteIssue ¶
func (r *RedisAlertCache) DeleteIssue(id string) *nerr.E
func (*RedisAlertCache) GetAllIssues ¶
func (r *RedisAlertCache) GetAllIssues() ([]structs.RoomIssue, *nerr.E)
Click to show internal directories.
Click to hide internal directories.